@@ -29,7 +29,6 @@ import htsjdk.samtools.SAMReadGroupRecord;
 import htsjdk.samtools.SAMRecord;
 import htsjdk.samtools.metrics.MetricsFile;
 import htsjdk.samtools.reference.ReferenceSequence;
-import htsjdk.samtools.util.Histogram;
 import htsjdk.samtools.util.IOUtil;
 import htsjdk.samtools.util.Log;
 import htsjdk.samtools.util.StringUtil;
@@ -95,77 +94,6 @@ public class MeanQualityByCycle extends SinglePassSamProgram {
 
     private final Log log = Log.getInstance(MeanQualityByCycle.class);
 
-    private static final class HistogramGenerator {
-        final boolean useOriginalQualities;
-        int maxLengthSoFar = 0;
-        double[] firstReadTotalsByCycle  = new double[maxLengthSoFar];
-        long[]   firstReadCountsByCycle  = new long[maxLengthSoFar];
-        double[] secondReadTotalsByCycle = new double[maxLengthSoFar];
-        long[]   secondReadCountsByCycle = new long[maxLengthSoFar];
-
-        private HistogramGenerator(final boolean useOriginalQualities) {
-            this.useOriginalQualities = useOriginalQualities;
-        }
-
-        void addRecord(final SAMRecord rec) {
-            final byte[] quals = (useOriginalQualities ? rec.getOriginalBaseQualities() : rec.getBaseQualities());
-            if (quals == null) return;
-
-            final int length = quals.length;
-            final boolean rc = rec.getReadNegativeStrandFlag();
-            ensureArraysBigEnough(length+1);
-
-            for (int i=0; i<length; ++i) {
-                final int cycle = rc ? length-i : i+1;
-
-                if (rec.getReadPairedFlag() && rec.getSecondOfPairFlag()) {
-                    secondReadTotalsByCycle[cycle] += quals[i];
-                    secondReadCountsByCycle[cycle] += 1;
-                }
-                else {
-                    firstReadTotalsByCycle[cycle] += quals[i];
-                    firstReadCountsByCycle[cycle] += 1;
-                }
-            }
-        }
-
-        private void ensureArraysBigEnough(final int length) {
-            if (length > maxLengthSoFar) {
-                firstReadTotalsByCycle  = Arrays.copyOf(firstReadTotalsByCycle, length);
-                firstReadCountsByCycle  = Arrays.copyOf(firstReadCountsByCycle, length);
-                secondReadTotalsByCycle = Arrays.copyOf(secondReadTotalsByCycle , length);
-                secondReadCountsByCycle = Arrays.copyOf(secondReadCountsByCycle, length);
-                maxLengthSoFar = length;
-            }
-        }
-
-        Histogram<Integer> getMeanQualityHistogram() {
-            final String label = useOriginalQualities ? "MEAN_ORIGINAL_QUALITY" : "MEAN_QUALITY";
-            final Histogram<Integer> meanQualities = new Histogram<Integer>("CYCLE", label);
-
-            int firstReadLength = 0;
-
-            for (int cycle=0; cycle < firstReadTotalsByCycle.length; ++cycle) {
-                if (firstReadTotalsByCycle[cycle] > 0) {
-                    meanQualities.increment(cycle, firstReadTotalsByCycle[cycle] / firstReadCountsByCycle[cycle]);
-                    firstReadLength = cycle;
-                }
-            }
-
-            for (int i=0; i< secondReadTotalsByCycle.length; ++i) {
-                if (secondReadCountsByCycle[i] > 0) {
-                    final int cycle = firstReadLength + i;
-                    meanQualities.increment(cycle, secondReadTotalsByCycle[i] / secondReadCountsByCycle[i]);
-                }
-            }
-
-            return meanQualities;
-        }
-
-        boolean isEmpty() {
-            return maxLengthSoFar == 0;
-        }
-    }
 
     @Override
     protected String[] customCommandLineValidation() {
