@@ -1,7 +1,10 @@
 package picard.arrays;
 
 import htsjdk.samtools.metrics.MetricBase;
+import org.broadinstitute.barclay.help.DocumentedFeature;
+import picard.util.help.HelpConstants;
 
+@DocumentedFeature(groupName = HelpConstants.DOC_CAT_METRICS, summary = HelpConstants.DOC_CAT_METRICS_SUMMARY)
 public class VerifyIDIntensityContaminationMetrics extends MetricBase {
     /** The ID of this entry */
     public int ID;
