@@ -223,9 +223,13 @@ public class FingerprintChecker {
         final SAMSequenceDictionary activeDictionary = getActiveDictionary(haplotypes);
 
         if (sequenceDictionaryToCheck.getSequences().size() < activeDictionary.size()) {
-            throw new IllegalArgumentException("Dictionary on fingerprinted file smaller than that on Haplotype Database!");
+            throw new SequenceUtil.SequenceListsDifferException("Dictionary on fingerprinted file smaller than that on Haplotype Database!");
+        }
+        try {
+            SequenceUtil.assertSequenceDictionariesEqual(activeDictionary, sequenceDictionaryToCheck, true);
+        } catch (final SequenceUtil.SequenceListsDifferException e) {
+            throw new PicardException("Dictionary on fingerprinted file does not match dictionary in Haplotype Database.", e);
         }
-        SequenceUtil.assertSequenceDictionariesEqual(activeDictionary, sequenceDictionaryToCheck, true);
     }
 
     private static SAMSequenceDictionary getActiveDictionary(final HaplotypeMap haplotypes) {
@@ -531,7 +535,15 @@ public class FingerprintChecker {
             log.info(String.format("Reading an indexed file (%s)", samFile.toUri().toString()));
         }
 
-        final SamLocusIterator iterator = new SamLocusIterator(in, this.haplotypes.getIntervalList(), in.hasIndex());
+        // fingerprinting allows that headers differ, but SamLocusIterator doesn't allow the dictionary of the query
+        // interval list to differ from that of the samfile, leading to an exception thrown.
+        // At this point we already know that the dictionary of the haplotypes is a proper prefix of that of the sam file
+        // So we just swap out the header in the interval list.
+        final IntervalList il = this.haplotypes.getIntervalList();
+        final IntervalList newIl = new IntervalList(in.getFileHeader());
+        newIl.addall(il.getIntervals());
+
+        final SamLocusIterator iterator = new SamLocusIterator(in, newIl, in.hasIndex());
         iterator.setEmitUncoveredLoci(true);
         iterator.setMappingQualityScoreCutoff(this.minimumMappingQuality);
         iterator.setQualityScoreCutoff(this.minimumBaseQuality);
@@ -774,7 +786,7 @@ public class FingerprintChecker {
 
                 final FingerprintResults results = new FingerprintResults(p, null, specificSample);
                 for (final Fingerprint expectedFp : expectedFingerprints) {
-                    final MatchResults result = calculateMatchResults(combinedFp, expectedFp, 0, pLossofHet);
+                    final MatchResults result = calculateMatchResults(combinedFp, expectedFp, pLossofHet);
                     results.addResults(result);
                 }
 
@@ -784,7 +796,7 @@ public class FingerprintChecker {
                 for (final FingerprintIdDetails rg : fingerprintsByReadGroup.keySet()) {
                     final FingerprintResults results = new FingerprintResults(p, rg.platformUnit, rg.sample);
                     for (final Fingerprint expectedFp : expectedFingerprints) {
-                        final MatchResults result = calculateMatchResults(fingerprintsByReadGroup.get(rg), expectedFp, 0, pLossofHet);
+                        final MatchResults result = calculateMatchResults(fingerprintsByReadGroup.get(rg), expectedFp, pLossofHet);
                         results.addResults(result);
                     }
 
@@ -831,7 +843,7 @@ public class FingerprintChecker {
             for (final String sample : observedFingerprintsBySample.keySet()) {
                 final FingerprintResults results = new FingerprintResults(p, null, sample);
                 for (final Fingerprint expectedFp : expectedFingerprints) {
-                    final MatchResults result = calculateMatchResults(observedFingerprintsBySample.get(sample), expectedFp, 0, pLossofHet);
+                    final MatchResults result = calculateMatchResults(observedFingerprintsBySample.get(sample), expectedFp, pLossofHet);
                     results.addResults(result);
                 }
                 resultsList.add(results);
@@ -840,8 +852,8 @@ public class FingerprintChecker {
         return resultsList;
     }
 
-    public static MatchResults calculateMatchResults(final Fingerprint observedFp, final Fingerprint expectedFp, final double minPExpected, final double pLoH) {
-        return calculateMatchResults(observedFp, expectedFp, minPExpected, pLoH, true, true);
+    public static MatchResults calculateMatchResults(final Fingerprint observedFp, final Fingerprint expectedFp, final double pLoH) {
+        return calculateMatchResults(observedFp, expectedFp, pLoH, true, true);
 
     }
 
@@ -856,7 +868,7 @@ public class FingerprintChecker {
      * In the cases where the most likely genotypes from the two fingerprints do not match the
      * lExpectedSample is Max(actualpExpectedSample, minPExpected).
      */
-    public static MatchResults calculateMatchResults(final Fingerprint observedFp, final Fingerprint expectedFp, final double minPExpected, final double pLoH, final boolean calculateLocusInfo, final boolean calculateTumorAwareLod) {
+    public static MatchResults calculateMatchResults(final Fingerprint observedFp, final Fingerprint expectedFp, final double pLoH, final boolean calculateLocusInfo, final boolean calculateTumorAwareLod) {
         final List<LocusResult> locusResults = calculateLocusInfo ? new ArrayList<>() : null;
 
         double llNoSwapModel = 0;
@@ -934,7 +946,7 @@ public class FingerprintChecker {
      * as the observedFp and the genotype data as the expectedFp in order to get the best output.
      */
     public static MatchResults calculateMatchResults(final Fingerprint observedFp, final Fingerprint expectedFp) {
-        return calculateMatchResults(observedFp, expectedFp, 0, 0);
+        return calculateMatchResults(observedFp, expectedFp, 0);
     }
 
     public void setReferenceFasta(final File referenceFasta) {
