@@ -24,13 +24,9 @@
 
 package picard.fingerprint;
 
-import htsjdk.samtools.util.CollectionUtil;
-
-import java.util.Map;
-
 /**
  * A wrapper class for any HaplotypeProbabilities instance that will assume that the given evidence is that of a tumor sample and
- * provide an hp for the normal sample that tumor came from. This models possible loss of hetrozygosity where het genotypes
+ * provide an hp for the normal sample that tumor came from. This models possible loss of heterozygosity where het genotypes
  * turn into a homozygous genotype with probability pLoH.
  * <p>
  * The shortcoming of this model is that we assume that the events are all independent, but this way they are allowed.
@@ -39,10 +35,17 @@ import java.util.Map;
  */
 
 public class HaplotypeProbabilityOfNormalGivenTumor extends HaplotypeProbabilities {
-    static private class TransitionMatrix {
+    public HaplotypeProbabilityOfNormalGivenTumor(final HaplotypeProbabilityOfNormalGivenTumor other) {
+        super(other.getHaplotype());
+        transitionMatrix = other.transitionMatrix;
+
+        hpOfTumor = other.hpOfTumor.deepCopy();
+    }
+
+    private static class TransitionMatrixGenerator {
         private final double[][] transitionMatrix;
 
-        public TransitionMatrix(double pLoH) {
+        TransitionMatrixGenerator(double pLoH) {
             transitionMatrix = new double[][]{
                     //This is P(g_t|g_n)
                     //tumor genotype are the columns.
@@ -51,20 +54,18 @@ public class HaplotypeProbabilityOfNormalGivenTumor extends HaplotypeProbabiliti
                     {0, 0, 1}}; //normal is hom_var => tumor must be the same
         }
 
-        public double[][] getTransitionMatrix() {
+        double[][] get() {
             return transitionMatrix;
         }
     }
 
     private final HaplotypeProbabilities hpOfTumor;
-    static private Map<Double, TransitionMatrix> transitionMatrixMap = new CollectionUtil.DefaultingMap<>(TransitionMatrix::new, true);
-
-    final private double[][] transitionMatrix;
+    private final TransitionMatrixGenerator transitionMatrix;
 
     public HaplotypeProbabilityOfNormalGivenTumor(final HaplotypeProbabilities hpOfTumor, final double pLoH) {
         super(hpOfTumor.getHaplotype());
-        transitionMatrix = transitionMatrixMap.get(pLoH).getTransitionMatrix();
         this.hpOfTumor = hpOfTumor;
+        transitionMatrix = new TransitionMatrixGenerator(pLoH);
     }
 
     // This function needs to be overridden since we want likelihood to mean the probability of the
@@ -84,7 +85,7 @@ public class HaplotypeProbabilityOfNormalGivenTumor extends HaplotypeProbabiliti
         for (final Genotype g_n : Genotype.values()) {
             normalHaplotypeLikelihoods[g_n.v] = 0D;
             for (final Genotype g_t : Genotype.values()) {
-                normalHaplotypeLikelihoods[g_n.v] += tumorHaplotypeLikelihoods[g_t.v] * transitionMatrix[g_n.v][g_t.v];
+                normalHaplotypeLikelihoods[g_n.v] += tumorHaplotypeLikelihoods[g_t.v] * transitionMatrix.get()[g_n.v][g_t.v];
             }
         }
         return normalHaplotypeLikelihoods;
@@ -96,8 +97,23 @@ public class HaplotypeProbabilityOfNormalGivenTumor extends HaplotypeProbabiliti
     }
 
     @Override
-    public void merge(final HaplotypeProbabilities ignored) {
-        throw new IllegalArgumentException("Cannot merge HaplotypeProbabilityOfNormalGivenTumor. Merge the underlying object and create a new wrapper.");
+    public HaplotypeProbabilityOfNormalGivenTumor merge(final HaplotypeProbabilities other) {
+        if (!this.getHaplotype().equals(other.getHaplotype())) {
+            throw new IllegalArgumentException("Mismatched haplotypes in call to HaplotypeProbabilities.merge(): " +
+                    getHaplotype() + ", " + other.getHaplotype());
+        }
+
+        if (!(other instanceof HaplotypeProbabilityOfNormalGivenTumor)) {
+            throw new IllegalArgumentException("Can only merge HaplotypeProbabilities of same class.");
+        }
+
+        this.hpOfTumor.merge(((HaplotypeProbabilityOfNormalGivenTumor) other).hpOfTumor);
+        return this;
+    }
+
+    @Override
+    public HaplotypeProbabilityOfNormalGivenTumor deepCopy() {
+        return new HaplotypeProbabilityOfNormalGivenTumor(this);
     }
 
     @Override
