@@ -1,7 +1,7 @@
 /*
  * The MIT License
  *
- * Copyright (c) 2011 The Broad Institute
+ * Copyright (c) 2011-2016 The Broad Institute
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -24,7 +24,13 @@
 
 package picard.illumina;
 
-import htsjdk.samtools.*;
+import htsjdk.samtools.BAMRecordCodec;
+import htsjdk.samtools.SAMFileHeader;
+import htsjdk.samtools.SAMFileWriter;
+import htsjdk.samtools.SAMFileWriterFactory;
+import htsjdk.samtools.SAMReadGroupRecord;
+import htsjdk.samtools.SAMRecord;
+import htsjdk.samtools.SAMRecordQueryNameComparator;
 import htsjdk.samtools.util.CollectionUtil;
 import htsjdk.samtools.util.IOUtil;
 import htsjdk.samtools.util.Iso8601Date;
@@ -35,10 +41,8 @@ import org.broadinstitute.barclay.argparser.Argument;
 import org.broadinstitute.barclay.argparser.CommandLineProgramProperties;
 import org.broadinstitute.barclay.help.DocumentedFeature;
 import picard.PicardException;
-import picard.cmdline.CommandLineProgram;
 import picard.cmdline.StandardOptionDefinitions;
 import picard.cmdline.programgroups.BaseCallingProgramGroup;
-import picard.illumina.parser.IlluminaFileUtil;
 import picard.illumina.parser.ReadStructure;
 import picard.illumina.parser.readers.BclQualityEvaluationStrategy;
 import picard.util.AdapterPair;
@@ -47,6 +51,7 @@ import picard.util.IlluminaUtil.IlluminaAdapterPair;
 import picard.util.TabbedTextFileWithHeaderParser;
 
 import java.io.File;
+import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
 import java.util.ArrayList;
@@ -59,14 +64,15 @@ import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
+import java.util.stream.Collectors;
 
 /**
  * IlluminaBasecallsToSam transforms a lane of Illumina data file formats (bcl, locs, clocs, qseqs, etc.) into
- * SAM or BAM file format.
+ * SAM, BAM or CRAM file format.
  * <p/>
  * In this application, barcode data is read from Illumina data file groups, each of which is associated with a tile.
  * Each tile may contain data for any number of barcodes, and a single barcode's data may span multiple tiles.  Once the
- * barcode data is collected from files, each barcode's data is written to its own SAM/BAM.  The barcode data must be
+ * barcode data is collected from files, each barcode's data is written to its own SAM/BAM/CRAM.  The barcode data must be
  * written in order; this means that barcode data from each tile is sorted before it is written to file, and that if a
  * barcode's data does span multiple tiles, data collected from each tile must be written in the order of the tiles
  * themselves.
@@ -95,10 +101,10 @@ import java.util.Set;
         programGroup = BaseCallingProgramGroup.class
 )
 @DocumentedFeature
-public class IlluminaBasecallsToSam extends CommandLineProgram {
-    static final String USAGE_SUMMARY = "Transforms raw Illumina sequencing data into an unmapped SAM or BAM file.";
+public class IlluminaBasecallsToSam extends ExtractBarcodesProgram {
+    static final String USAGE_SUMMARY = "Transforms raw Illumina sequencing data into an unmapped SAM, BAM or CRAM file.";
     static final String USAGE_DETAILS = "<p>The IlluminaBaseCallsToSam program collects, demultiplexes, and sorts reads across all " +
-            "of the tiles of a lane via barcode to produce an unmapped SAM/BAM file.  An unmapped BAM file is often referred to as a uBAM.  " +
+            "of the tiles of a lane via barcode to produce an unmapped SAM, BAM or CRAM file.  An unmapped BAM file is often referred to as a uBAM.  " +
             "All barcode, sample, and library data is provided in the LIBRARY_PARAMS file.  Note, this LIBRARY_PARAMS file " +
             "should be formatted according to the specifications indicated below.  The following is an example of a properly" +
             " formatted LIBRARY_PARAMS file:</p>" +
@@ -111,7 +117,11 @@ public class IlluminaBasecallsToSam extends CommandLineProgram {
             "<p>The BARCODES_DIR file is produced by the " +
             "<a href='http://broadinstitute.github.io/picard/command-line-overview.html#ExtractIlluminaBarcodes'>ExtractIlluminaBarcodes</a> " +
             "tool for each lane of a flow cell.</p>  " +
-
+            "" +
+            "<p>Barcode matching can be done inline without requiring barcodes files generated by `ExtractIlluminaBarcode`. " +
+            "By setting MATCH_BARCODES_INLINE to true barcodes will be matched as they are parsed and converted. This" +
+            "does not require BARCODES_DIR.</p>     " +
+            "" +
             "<h4>Usage example:</h4>" +
             "<pre>" +
             "" +
@@ -128,18 +138,12 @@ public class IlluminaBasecallsToSam extends CommandLineProgram {
 
     // The following attributes define the command-line arguments
 
-    public static final String USAGE = "Generate a SAM or BAM file from data in an Illumina basecalls output directory";
-
-    @Argument(doc = "The basecalls directory. ", shortName = "B")
-    public File BASECALLS_DIR;
+    public static final String USAGE = "Generate a SAM, BAM or CRAM file from data in an Illumina basecalls output directory";
 
     @Argument(doc = "The barcodes directory with _barcode.txt files (generated by ExtractIlluminaBarcodes). If not set, use BASECALLS_DIR. ", shortName = "BCD", optional = true)
     public File BARCODES_DIR;
 
-    @Argument(doc = "Lane number. ", shortName = StandardOptionDefinitions.LANE_SHORT_NAME)
-    public Integer LANE;
-
-    @Argument(doc = "Deprecated (use LIBRARY_PARAMS).  The output SAM or BAM file. Format is determined by extension.",
+    @Argument(doc = "Deprecated (use LIBRARY_PARAMS).  The output SAM, BAM or CRAM file. Format is determined by extension.",
             shortName = StandardOptionDefinitions.OUTPUT_SHORT_NAME,
             mutex = {"BARCODE_PARAMS", "LIBRARY_PARAMS"})
     public File OUTPUT;
@@ -176,21 +180,18 @@ public class IlluminaBasecallsToSam extends CommandLineProgram {
     @Argument(doc = "Whether to include the barcode information in the @RG->BC header tag. Defaults to false until included in the SAM spec.")
     public boolean INCLUDE_BC_IN_RG_TAG = false;
 
-    @Argument(doc = ReadStructure.PARAMETER_DOC, shortName = "RS")
-    public String READ_STRUCTURE;
-
-    @Argument(doc = "Deprecated (use LIBRARY_PARAMS).  Tab-separated file for creating all output BAMs for barcoded run " +
+    @Argument(doc = "Deprecated (use LIBRARY_PARAMS).  Tab-separated file for creating all output SAM, BAM or CRAM files for barcoded run " +
             "with single IlluminaBasecallsToSam invocation.  Columns are BARCODE, OUTPUT, SAMPLE_ALIAS, and " +
             "LIBRARY_NAME.  Row with BARCODE=N is used to specify a file for no barcode match",
             mutex = {"OUTPUT", "SAMPLE_ALIAS", "LIBRARY_NAME", "LIBRARY_PARAMS"})
     public File BARCODE_PARAMS;
 
-    @Argument(doc = "Tab-separated file for creating all output BAMs for a lane with single IlluminaBasecallsToSam " +
+    @Argument(doc = "Tab-separated file for creating all output SAM, BAM or CRAM files for a lane with single IlluminaBasecallsToSam " +
             "invocation.  The columns are OUTPUT, SAMPLE_ALIAS, and LIBRARY_NAME, BARCODE_1, BARCODE_2 ... BARCODE_X " +
             "where X = number of barcodes per cluster (optional).  Row with BARCODE_1 set to 'N' is used to specify a file " +
             "for no barcode match.  You may also provide any 2 letter RG header attributes (excluding PU, CN, PL, and" +
             " DT)  as columns in this file and the values for those columns will be inserted into the RG tag for the" +
-            " BAM file created for a given row.",
+            " SAM, BAM or CRAM file created for a given row.",
             mutex = {"OUTPUT", "SAMPLE_ALIAS", "LIBRARY_NAME", "BARCODE_PARAMS"})
     public File LIBRARY_PARAMS;
 
@@ -226,27 +227,19 @@ public class IlluminaBasecallsToSam extends CommandLineProgram {
             optional = true)
     public Integer PROCESS_SINGLE_TILE;
 
-    @Argument(doc = "If true, call System.gc() periodically.  This is useful in cases in which the -Xmx value passed " +
-            "is larger than the available memory.")
-    public Boolean FORCE_GC = true;
-
     @Argument(doc = "Apply EAMSS filtering to identify inappropriately quality scored bases towards the ends of reads" +
             " and convert their quality scores to Q2.")
     public boolean APPLY_EAMSS_FILTER = true;
 
     @Argument(doc = "Configure SortingCollections to store this many records before spilling to disk. For an indexed" +
-            " run, each SortingCollection gets this value/number of indices.")
-    public int MAX_READS_IN_RAM_PER_TILE = 1200000;
-
-    @Argument(doc = "The minimum quality (after transforming 0s to 1s) expected from reads.  If qualities are lower than this value, an error is thrown." +
-            "The default of 2 is what the Illumina's spec describes as the minimum, but in practice the value has been observed lower.")
-    public int MINIMUM_QUALITY = BclQualityEvaluationStrategy.ILLUMINA_ALLEGED_MINIMUM_QUALITY;
+            " run, each SortingCollection gets this value/number of indices. Deprecated: use `MAX_RECORDS_IN_RAM`")
+    public int MAX_READS_IN_RAM_PER_TILE = -1;
 
     @Argument(doc = "Whether to include non-PF reads", shortName = "NONPF", optional = true)
     public boolean INCLUDE_NON_PF_READS = true;
 
     @Argument(doc = "Whether to ignore reads whose barcodes are not found in LIBRARY_PARAMS.  Useful when outputting " +
-            "BAMs for only a subset of the barcodes in a lane.", shortName = "IGNORE_UNEXPECTED")
+            "SAM, BAM or CRAM files for only a subset of the barcodes in a lane.", shortName = "IGNORE_UNEXPECTED")
     public boolean IGNORE_UNEXPECTED_BARCODES = false;
 
     @Argument(doc = "The tag to use to store any molecular indexes.  If more than one molecular index is found, they will be concatenated and stored here.", optional = true)
@@ -265,15 +258,31 @@ public class IlluminaBasecallsToSam extends CommandLineProgram {
     @Argument(doc = "Should the barcode quality be included when the sample barcode is included?")
     public boolean INCLUDE_BARCODE_QUALITY = false;
 
-    private final Map<String, SAMFileWriterWrapper> barcodeSamWriterMap = new HashMap<>();
+    @Argument(doc = "If true, the output records are sorted by read name. Otherwise they are unsorted.")
+    public Boolean SORT = true;
+
+    @Argument(doc = "If true, match barcodes on the fly. Otherwise parse the barcodes from the barcodes file.")
+    public Boolean MATCH_BARCODES_INLINE = false;
+
+    private Map<String, SAMFileWriterWrapper> barcodeSamWriterMap;
     private ReadStructure readStructure;
     private BasecallsConverter<SAMRecordsForCluster> basecallsConverter;
     private static final Log log = Log.getInstance(IlluminaBasecallsToSam.class);
+    private final BclQualityEvaluationStrategy bclQualityEvaluationStrategy = new BclQualityEvaluationStrategy(MINIMUM_QUALITY);
+    private final Map<Integer, String> laneToReadGroupId = new HashMap<>();
 
     @Override
     protected int doWork() {
         initialize();
-        basecallsConverter.doTileProcessing();
+        try {
+            basecallsConverter.processTilesAndWritePerSampleOutputs(barcodeSamWriterMap.keySet());
+            if (METRICS_FILE != null && MATCH_BARCODES_INLINE) {
+                finalizeMetrics(barcodeToMetrics, noMatchMetric);
+                outputMetrics();
+            }
+        } catch (IOException e) {
+            throw new PicardException("Error converting basecalls to SAM.", e);
+        }
         return 0;
     }
 
@@ -281,8 +290,10 @@ public class IlluminaBasecallsToSam extends CommandLineProgram {
      * Prepares loggers, initiates garbage collection thread, parses arguments and initialized variables appropriately/
      */
     private void initialize() {
-        final BclQualityEvaluationStrategy bclQualityEvaluationStrategy = new BclQualityEvaluationStrategy(MINIMUM_QUALITY);
-
+        IOUtil.assertDirectoryIsReadable(BASECALLS_DIR);
+        if (BARCODES_DIR != null) {
+            IOUtil.assertDirectoryIsReadable(BARCODES_DIR);
+        }
         if (OUTPUT != null) {
             IOUtil.assertFileIsWritable(OUTPUT);
         }
@@ -292,40 +303,55 @@ public class IlluminaBasecallsToSam extends CommandLineProgram {
         }
 
         if (OUTPUT != null) {
-            barcodeSamWriterMap.put(null, buildSamFileWriter(OUTPUT, SAMPLE_ALIAS, LIBRARY_NAME, buildSamHeaderParameters(null), true));
+            barcodeSamWriterMap = new HashMap<>(1, 1.0f);
+            barcodeSamWriterMap.put(null, buildSamFileWriter(OUTPUT, SAMPLE_ALIAS, LIBRARY_NAME, buildSamHeaderParameters(null), SORT));
         } else {
             populateWritersFromLibraryParams();
         }
 
         final int numOutputRecords = readStructure.templates.length();
+
         // Combine any adapters and custom adapter pairs from the command line into an array for use in clipping
         final List<AdapterPair> adapters = new ArrayList<>(ADAPTERS_TO_CHECK);
-
         if (FIVE_PRIME_ADAPTER != null && THREE_PRIME_ADAPTER != null) {
             adapters.add(new CustomAdapterPair(FIVE_PRIME_ADAPTER, THREE_PRIME_ADAPTER));
         }
 
         final boolean demultiplex = readStructure.hasSampleBarcode();
-        if (IlluminaFileUtil.hasCbcls(BASECALLS_DIR, LANE)) {
-            if (BARCODES_DIR == null) BARCODES_DIR = BASECALLS_DIR;
-            basecallsConverter = new NewIlluminaBasecallsConverter<>(BASECALLS_DIR, BARCODES_DIR, LANE, readStructure,
-                    barcodeSamWriterMap, demultiplex, Math.max(1, MAX_READS_IN_RAM_PER_TILE / numOutputRecords),
-                    TMP_DIR, NUM_PROCESSORS,
-                    FIRST_TILE, TILE_LIMIT, new QueryNameComparator(),
-                    new Codec(numOutputRecords),
-                    SAMRecordsForCluster.class, bclQualityEvaluationStrategy, IGNORE_UNEXPECTED_BARCODES);
+        BasecallsConverterBuilder<SAMRecordsForCluster> converterBuilder = new BasecallsConverterBuilder<>(BASECALLS_DIR, LANE.stream().mapToInt(i->i).toArray(), readStructure, barcodeSamWriterMap)
+                .withBarcodesDir(BARCODES_DIR)
+                .withDemultiplex(demultiplex)
+                .numProcessors(NUM_PROCESSORS)
+                .firstTile(FIRST_TILE)
+                .tileLimit(TILE_LIMIT)
+                .withApplyEamssFiltering(APPLY_EAMSS_FILTER)
+                .withIncludeNonPfReads(INCLUDE_NON_PF_READS)
+                .withIgnoreUnexpectedBarcodes(IGNORE_UNEXPECTED_BARCODES)
+                .withBclQualityEvaluationStrategy(bclQualityEvaluationStrategy)
+                .withMaxRecordsInRam(MAX_RECORDS_IN_RAM);
+
+        if (MATCH_BARCODES_INLINE && demultiplex) {
+            converterBuilder = converterBuilder.withBarcodeExtractor(createBarcodeExtractor()).withBarcodesDir(null);
         } else {
-            basecallsConverter = new IlluminaBasecallsConverter<>(BASECALLS_DIR, BARCODES_DIR, LANE, readStructure,
-                    barcodeSamWriterMap, demultiplex, MAX_READS_IN_RAM_PER_TILE / numOutputRecords, TMP_DIR, NUM_PROCESSORS, FORCE_GC,
-                    FIRST_TILE, TILE_LIMIT, new QueryNameComparator(), new Codec(numOutputRecords), SAMRecordsForCluster.class,
-                    bclQualityEvaluationStrategy, APPLY_EAMSS_FILTER, INCLUDE_NON_PF_READS, IGNORE_UNEXPECTED_BARCODES);
+            converterBuilder = BARCODES_DIR == null ? converterBuilder.withBarcodesDir(BASECALLS_DIR) : converterBuilder.withBarcodesDir(BARCODES_DIR);
         }
+
+        if (SORT) {
+            converterBuilder = converterBuilder
+                    .withSorting(
+                            new QueryNameComparator(),
+                            new Codec(numOutputRecords),
+                            SAMRecordsForCluster.class,
+                            TMP_DIR);
+        }
+
+        basecallsConverter = converterBuilder.build();
         /*
          * Be sure to pass the outputReadStructure to ClusterDataToSamConverter, which reflects the structure of the output cluster
          * data which may be different from the input read structure (specifically if there are skips).
          */
-        final ClusterDataToSamConverter converter = new ClusterDataToSamConverter(RUN_BARCODE, READ_GROUP_ID,
-                basecallsConverter.getFactory().getOutputReadStructure(), adapters, BARCODE_POPULATION_STRATEGY, INCLUDE_BARCODE_QUALITY )
+        final ClusterDataToSamConverter converter = new ClusterDataToSamConverter(RUN_BARCODE, laneToReadGroupId,
+                basecallsConverter.getLaneFactories()[0].getOutputReadStructure(), adapters, BARCODE_POPULATION_STRATEGY, INCLUDE_BARCODE_QUALITY)
                 .withMolecularIndexTag(MOLECULAR_INDEX_TAG)
                 .withMolecularIndexQualityTag(MOLECULAR_INDEX_BASE_QUALITY_TAG)
                 .withTagPerMolecularIndex(TAG_PER_MOLECULAR_INDEX);
@@ -406,7 +432,10 @@ public class IlluminaBasecallsToSam extends CommandLineProgram {
         final Set<String> rgTagColumns = findAndFilterExpectedColumns(libraryParamsParser.columnLabels(), expectedColumnLabels);
         checkRgTagColumns(rgTagColumns);
 
-        for (final TabbedTextFileWithHeaderParser.Row row : libraryParamsParser) {
+        final List<TabbedTextFileWithHeaderParser.Row> rows = libraryParamsParser.iterator().toList();
+        barcodeSamWriterMap = new HashMap<>(rows.size(), 1);
+
+        for (final TabbedTextFileWithHeaderParser.Row row : rows) {
             List<String> barcodeValues = null;
 
             if (!barcodeColumnLabels.isEmpty()) {
@@ -438,7 +467,7 @@ public class IlluminaBasecallsToSam extends CommandLineProgram {
             }
 
             final SAMFileWriterWrapper writer = buildSamFileWriter(outputFile,
-                    row.getField("SAMPLE_ALIAS"), row.getField("LIBRARY_NAME"), samHeaderParams, true);
+                    row.getField("SAMPLE_ALIAS"), row.getField("LIBRARY_NAME"), samHeaderParams, SORT);
             barcodeSamWriterMap.put(key, writer);
         }
         if (barcodeSamWriterMap.isEmpty()) {
@@ -458,7 +487,7 @@ public class IlluminaBasecallsToSam extends CommandLineProgram {
     private Map<String, String> buildSamHeaderParameters(final List<String> barcodes) {
         final Map<String, String> params = new LinkedHashMap<>();
 
-        String platformUnit = RUN_BARCODE + "." + LANE;
+        String platformUnit = RUN_BARCODE + "." + LANE.stream().map(Object::toString).collect(Collectors.joining(","));
         if (barcodes != null) {
             final String barcodeString = IlluminaUtil.barcodeSeqsToString(barcodes);
             platformUnit += "." + barcodeString;
@@ -493,21 +522,31 @@ public class IlluminaBasecallsToSam extends CommandLineProgram {
                                                     final String libraryName, final Map<String, String> headerParameters,
                                                     final boolean presorted) {
         IOUtil.assertFileIsWritable(output);
-        final SAMReadGroupRecord rg = new SAMReadGroupRecord(READ_GROUP_ID);
-        rg.setSample(sampleAlias);
+        final List<SAMReadGroupRecord> rgs = LANE.stream().map(lane -> {
+            SAMReadGroupRecord rgr = new SAMReadGroupRecord(READ_GROUP_ID + "." + lane);
+            rgr.setSample(sampleAlias);
 
-        if (libraryName != null) rg.setLibrary(libraryName);
-        for (final Map.Entry<String, String> tagNameToValue : headerParameters.entrySet()) {
-            if (tagNameToValue.getValue() != null) {
-                rg.setAttribute(tagNameToValue.getKey(), tagNameToValue.getValue());
+            if (libraryName != null) rgr.setLibrary(libraryName);
+            for (final Map.Entry<String, String> tagNameToValue : headerParameters.entrySet()) {
+                if (tagNameToValue.getValue() != null) {
+                    rgr.setAttribute(tagNameToValue.getKey(), tagNameToValue.getValue());
+                }
             }
-        }
+            return rgr;
+        }).collect(Collectors.toList());
+
 
         final SAMFileHeader header = new SAMFileHeader();
 
-        header.setSortOrder(SAMFileHeader.SortOrder.queryname);
-        header.addReadGroup(rg);
-        return new SAMFileWriterWrapper(new SAMFileWriterFactory().makeSAMOrBAMWriter(header, presorted, output));
+        if (presorted) {
+            header.setSortOrder(SAMFileHeader.SortOrder.queryname);
+        } else {
+            header.setSortOrder(SAMFileHeader.SortOrder.unsorted);
+        }
+        for (SAMReadGroupRecord rg : rgs) {
+            header.addReadGroup(rg);
+        }
+        return new SAMFileWriterWrapper(new SAMFileWriterFactory().makeWriter(header, presorted, output, REFERENCE_SEQUENCE));
     }
 
     /**
@@ -520,9 +559,23 @@ public class IlluminaBasecallsToSam extends CommandLineProgram {
      */
     @Override
     protected String[] customCommandLineValidation() {
+
+        if (NUM_PROCESSORS == 0) {
+            NUM_PROCESSORS = Runtime.getRuntime().availableProcessors();
+        } else if (NUM_PROCESSORS < 0) {
+            NUM_PROCESSORS = Runtime.getRuntime().availableProcessors() + NUM_PROCESSORS;
+        }
+
         if (BARCODE_PARAMS != null) {
             LIBRARY_PARAMS = BARCODE_PARAMS;
         }
+        INPUT_PARAMS_FILE = LIBRARY_PARAMS;
+
+        // Remove once deprecated parameter is deleted.
+        if (MAX_READS_IN_RAM_PER_TILE != -1) {
+            log.warn("Setting deprecated parameter `MAX_READS_IN_RAM_PER_TILE` use ` MAX_RECORDS_IN_RAM` instead");
+            MAX_RECORDS_IN_RAM = MAX_READS_IN_RAM_PER_TILE * NUM_PROCESSORS;
+        }
 
         final ArrayList<String> messages = new ArrayList<>();
 
@@ -533,7 +586,12 @@ public class IlluminaBasecallsToSam extends CommandLineProgram {
         }
 
         if (READ_GROUP_ID == null) {
-            READ_GROUP_ID = RUN_BARCODE.substring(0, Math.min(RUN_BARCODE.length(), 5)) + "." + LANE;
+            READ_GROUP_ID = RUN_BARCODE.substring(0, Math.min(RUN_BARCODE.length(), 5));
+        }
+
+        // Build a map of lane to read group id.
+        for(Integer lane : LANE){
+            laneToReadGroupId.put(lane, READ_GROUP_ID + "." + lane);
         }
 
         if (!TAG_PER_MOLECULAR_INDEX.isEmpty() && TAG_PER_MOLECULAR_INDEX.size() != readStructure.molecularBarcode.length()) {
@@ -551,10 +609,8 @@ public class IlluminaBasecallsToSam extends CommandLineProgram {
             FIRST_TILE = PROCESS_SINGLE_TILE;
         }
 
-        if (messages.isEmpty()) {
-            return null;
-        }
-        return messages.toArray(new String[messages.size()]);
+        String[] superErrors = super.customCommandLineValidation();
+        return collectErrorMessages(messages, superErrors);
     }
 
     private static final class SAMFileWriterWrapper
