@@ -24,33 +24,18 @@
 
 package picard.illumina.parser;
 
-import htsjdk.samtools.util.IOUtil;
 import htsjdk.samtools.util.Log;
 import htsjdk.samtools.util.StringUtil;
 import picard.PicardException;
-import picard.illumina.NewIlluminaBasecallsConverter;
+import picard.illumina.SortedBasecallsConverter;
 import picard.illumina.parser.IlluminaFileUtil.SupportedIlluminaFormat;
-import picard.illumina.parser.readers.AbstractIlluminaPositionFileReader;
 import picard.illumina.parser.readers.BclQualityEvaluationStrategy;
 
 import java.io.File;
-import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.Collections;
-import java.util.EnumMap;
-import java.util.HashMap;
-import java.util.HashSet;
-import java.util.List;
-import java.util.Map;
-import java.util.Set;
-import java.util.SortedSet;
-import java.util.TreeSet;
-import java.util.regex.Matcher;
-import java.util.regex.Pattern;
+import java.util.*;
 
 import static htsjdk.samtools.util.CollectionUtil.makeList;
 import static htsjdk.samtools.util.CollectionUtil.makeSet;
-import static picard.illumina.NewIlluminaBasecallsConverter.getTiledFiles;
 
 /**
  * IlluminaDataProviderFactory accepts options for parsing Illumina data files for a lane and creates an
@@ -81,9 +66,9 @@ public class IlluminaDataProviderFactory {
          * see determineFormats
          */
         DATA_TYPE_TO_PREFERRED_FORMATS.put(IlluminaDataType.BaseCalls, makeList(
-                SupportedIlluminaFormat.MultiTileBcl, SupportedIlluminaFormat.Bcl));
+                SupportedIlluminaFormat.MultiTileBcl, SupportedIlluminaFormat.Bcl, SupportedIlluminaFormat.Cbcl));
         DATA_TYPE_TO_PREFERRED_FORMATS.put(IlluminaDataType.QualityScores, makeList(
-                SupportedIlluminaFormat.MultiTileBcl, SupportedIlluminaFormat.Bcl));
+                SupportedIlluminaFormat.MultiTileBcl, SupportedIlluminaFormat.Bcl, SupportedIlluminaFormat.Cbcl));
         DATA_TYPE_TO_PREFERRED_FORMATS.put(IlluminaDataType.PF, makeList(
                 SupportedIlluminaFormat.MultiTileFilter, SupportedIlluminaFormat.Filter));
         DATA_TYPE_TO_PREFERRED_FORMATS.put(IlluminaDataType.Position, makeList(
@@ -98,7 +83,15 @@ public class IlluminaDataProviderFactory {
      * basecallDirectory holds QSeqs or bcls *
      */
     private final File basecallDirectory;
+
+    /**
+     * barcodesDirectory holds the barcodes file generated by ExtractIlluminaBarcodes
+     */
     private final File barcodesDirectory;
+
+    /**
+     * The lane to read
+     */
     private final int lane;
 
     /**
@@ -117,7 +110,7 @@ public class IlluminaDataProviderFactory {
     private final IlluminaFileUtil fileUtil;
 
 
-    private List<Integer> availableTiles;
+    private final List<Integer> availableTiles;
 
     private final OutputMapping outputMapping;
     private final BclQualityEvaluationStrategy bclQualityEvaluationStrategy;
@@ -130,41 +123,45 @@ public class IlluminaDataProviderFactory {
      * @param readStructure     The read structure to which output clusters will conform.  When not using QSeqs, EAMSS masking(see BclParser) is run on individual reads as found in the readStructure, if
      *                          the readStructure specified does not match the readStructure implied by the sequencer's output than the quality scores output may differ than what would be found
      *                          in a run's QSeq files
-     * @param dataTypesArg      Which data types to read
+     * @param dataTypes      Which data types to read
      */
     public IlluminaDataProviderFactory(final File basecallDirectory, final int lane, final ReadStructure readStructure,
                                        final BclQualityEvaluationStrategy bclQualityEvaluationStrategy,
-                                       final IlluminaDataType... dataTypesArg) {
+                                       final Set<IlluminaDataType> dataTypes) {
         this(basecallDirectory, null,
                 lane, readStructure,
                 bclQualityEvaluationStrategy,
-                dataTypesArg);
+                dataTypes);
     }
 
     /**
      * Create factory with the specified options, one that favors using QSeqs over all other files
      *
-     * @param basecallDirectory The baseCalls directory of a complete Illumina directory.  Files are found by searching relative to this folder (some of them higher up in the directory tree).
-     * @param barcodesDirectory The barcodesDirectory with barcode files extracted by 'ExtractIlluminaBarcodes' (optional, use basecallDirectory if not specified)
-     * @param lane              Which lane to iterate over.
-     * @param readStructure     The read structure to which output clusters will conform.  When not using QSeqs, EAMSS masking(see BclParser) is run on individual reads as found in the readStructure, if
-     *                          the readStructure specified does not match the readStructure implied by the sequencer's output than the quality scores output may differ than what would be found
-     *                          in a run's QSeq files
-     * @param dataTypesArg      Which data types to read
+     * @param basecallDirectory            The baseCalls directory of a complete Illumina directory.  Files are found by searching relative to this folder (some of them higher up in the directory tree).
+     * @param barcodesDirectory            The barcodesDirectory with barcode files extracted by 'ExtractIlluminaBarcodes'. This will be set to `basecallsDirectory` if null.
+     * @param lane                         Which lane to iterate over.
+     * @param readStructure                The read structure to which output clusters will conform.  When not using QSeqs, EAMSS masking(see BclParser) is run on individual reads as found in the readStructure, if
+     *                                     the readStructure specified does not match the readStructure implied by the sequencer's output than the quality scores output may differ than what would be found
+     *                                     in a run's QSeq files
+     * @param bclQualityEvaluationStrategy The basecall quality evaluation strategy that is applyed to decoded base calls.
+     * @param dataTypes                 Which data types to read
      */
     public IlluminaDataProviderFactory(final File basecallDirectory, File barcodesDirectory, final int lane,
                                        final ReadStructure readStructure,
-                                       final BclQualityEvaluationStrategy bclQualityEvaluationStrategy, final IlluminaDataType... dataTypesArg) {
+                                       final BclQualityEvaluationStrategy bclQualityEvaluationStrategy, final Set<IlluminaDataType> dataTypes) {
         this.basecallDirectory = basecallDirectory;
-        this.barcodesDirectory = barcodesDirectory;
         this.bclQualityEvaluationStrategy = bclQualityEvaluationStrategy;
+        if (barcodesDirectory != null) {
+            this.barcodesDirectory = barcodesDirectory;
+        } else {
+            this.barcodesDirectory = basecallDirectory;
+        }
 
         this.lane = lane;
         /* The types of data that will be returned by any IlluminaDataProviders created by this factory.
           Note: In previous version, data of types not specified might be returned if a data type was specified
           for data residing in QSeqs (since QSeqs span multiple data types).  This is no longer the case, you
           MUST specify all data types that should be returned.*/
-        final Set<IlluminaDataType> dataTypes = Collections.unmodifiableSet(new HashSet<>(Arrays.asList(dataTypesArg)));
 
         if (dataTypes.isEmpty()) {
             throw new PicardException("No data types have been specified for basecall output " + basecallDirectory +
@@ -188,7 +185,7 @@ public class IlluminaDataProviderFactory {
         if (availableTiles.isEmpty()) {
             throw new PicardException("No available tiles were found, make sure that " + basecallDirectory.getAbsolutePath() + " has a lane " + lane);
         }
-        availableTiles.sort(NewIlluminaBasecallsConverter.TILE_NUMBER_COMPARATOR);
+        availableTiles.sort(SortedBasecallsConverter.TILE_NUMBER_COMPARATOR);
 
         //fill in available tiles for run based files
         formatToDataTypes.keySet().stream().map(fileUtil::getUtil)
@@ -197,39 +194,6 @@ public class IlluminaDataProviderFactory {
         outputMapping = new OutputMapping(readStructure);
     }
 
-    public IlluminaDataProviderFactory(File basecallDirectory, File barcodesDirectory, int lane,
-                                       ReadStructure readStructure,
-                                       BclQualityEvaluationStrategy bclQualityEvaluationStrategy) {
-        this.basecallDirectory = basecallDirectory;
-        this.barcodesDirectory = barcodesDirectory;
-        this.bclQualityEvaluationStrategy = bclQualityEvaluationStrategy;
-
-        this.lane = lane;
-
-        this.formatToDataTypes = null;
-        this.availableTiles = null;
-        this.fileUtil = null;
-
-        outputMapping = new OutputMapping(readStructure);
-
-        Pattern laneTileRegex = Pattern.compile(ParameterizedFileUtil.escapePeriods(
-                ParameterizedFileUtil.makeLaneTileRegex(".filter", lane)));
-        File laneDir = new File(basecallDirectory, IlluminaFileUtil.longLaneStr(lane));
-
-        List<Integer> tiles = new ArrayList<>();
-        File[] filterFiles = getTiledFiles(laneDir, laneTileRegex);
-        for (File filterFile : filterFiles) {
-            Matcher tileMatcher = laneTileRegex.matcher(filterFile.getName());
-            if (tileMatcher.matches()) {
-                tiles.add(Integer.valueOf(tileMatcher.group(1)));
-            }
-        }
-
-        IOUtil.assertFilesAreReadable(Arrays.asList(filterFiles));
-        tiles.sort(NewIlluminaBasecallsConverter.TILE_NUMBER_COMPARATOR);
-        availableTiles = tiles;
-    }
-
     /**
      * Sometimes (in the case of skipped reads) the logical read structure of the output cluster data is different from the input
      * readStructure
@@ -256,21 +220,12 @@ public class IlluminaDataProviderFactory {
         this.applyEamssFiltering = applyEamssFiltering;
     }
 
-    /**
-     * Call this method to create a ClusterData iterator over all clusters for a given tile.
-     *
-     * @param cbcls       A list of cbcls to use when creating this data provider.
-     * @param filterFiles A list of the pf filter files to use when creating this data provider.
-     * @return An iterator for reading the Illumina basecall output for the lane specified in the ctor.
-     */
-    public NewIlluminaDataProvider makeDataProvider(List<File> cbcls,
-                                                    List<AbstractIlluminaPositionFileReader.PositionInfo> locs,
-                                                    File[] filterFiles, int tileNum, File barcodeFile) {
-        return new NewIlluminaDataProvider(cbcls, locs, filterFiles, lane, tileNum, outputMapping, barcodeFile);
+    public BaseIlluminaDataProvider makeDataProvider() {
+        return makeDataProvider((List<Integer>) null);
     }
 
-    public BaseIlluminaDataProvider makeDataProvider() {
-        return makeDataProvider(null);
+   public BaseIlluminaDataProvider makeDataProvider(Integer requestedTile) {
+        return makeDataProvider(Collections.singletonList(requestedTile));
     }
 
     /**
@@ -286,15 +241,18 @@ public class IlluminaDataProviderFactory {
                 throw new PicardException("Zero length tile list supplied to makeDataProvider, you must specify at least 1 tile OR pass NULL to use all available tiles");
             }
         }
+        if (IlluminaFileUtil.hasCbcls(basecallDirectory, lane)) {
+            return new NewIlluminaDataProvider(outputMapping, basecallDirectory, barcodesDirectory, lane, requestedTiles);
+        } else {
+            final Map<IlluminaParser, Set<IlluminaDataType>> parsersToDataType = new HashMap<>();
+            for (final Map.Entry<SupportedIlluminaFormat, Set<IlluminaDataType>> fmToDt : formatToDataTypes.entrySet()) {
+                parsersToDataType.put(makeParser(fmToDt.getKey(), requestedTiles), fmToDt.getValue());
+            }
 
-        final Map<IlluminaParser, Set<IlluminaDataType>> parsersToDataType = new HashMap<>();
-        for (final Map.Entry<SupportedIlluminaFormat, Set<IlluminaDataType>> fmToDt : formatToDataTypes.entrySet()) {
-            parsersToDataType.put(makeParser(fmToDt.getKey(), requestedTiles), fmToDt.getValue());
+            log.debug("The following parsers will be used by IlluminaDataProvider: " + StringUtil.join("," + parsersToDataType.keySet()));
+
+            return new IlluminaDataProvider(outputMapping, parsersToDataType, basecallDirectory, lane);
         }
-
-        log.debug("The following parsers will be used by IlluminaDataProvider: " + StringUtil.join("," + parsersToDataType.keySet()));
-
-        return new IlluminaDataProvider(outputMapping, parsersToDataType, basecallDirectory, lane);
     }
 
     /**
