@@ -40,10 +40,6 @@ public class CalculateReadGroupChecksum extends CommandLineProgram {
     @Argument(shortName = StandardOptionDefinitions.OUTPUT_SHORT_NAME, doc = "The file to which the hash code should be written.", optional = true)
     public File OUTPUT;
 
-    public static void main(final String[] args) {
-        new CalculateReadGroupChecksum().instanceMainWithExit(args);
-    }
-
     /**
      * Creates a file name (not including the path) for an RG MD5 file based on the name of the input file.
      */
