@@ -555,7 +555,7 @@ public class MarkDuplicates extends AbstractMarkDuplicatesCommandLineProgram imp
 
                 if (rec.getReadPairedFlag() && !rec.getMateUnmappedFlag()) {
                     final StringBuilder key = new StringBuilder();
-                    key.append(ReservedTagConstants.READ_GROUP_ID);
+                    key.append(rec.getReadGroup().getReadGroupId());
                     key.append(rec.getReadName());
                     ReadEndsForMarkDuplicates pairedEnds = tmp.remove(rec.getReferenceIndex(), key.toString());
 
@@ -1035,10 +1035,10 @@ public class MarkDuplicates extends AbstractMarkDuplicatesCommandLineProgram imp
             // access to the index-in-file of the records (e.g. SPARK implmentations)
 
             if (compareDifference == 0) {
-                compareDifference = (int) (lhs.read1IndexInFile - rhs.read1IndexInFile);
+                compareDifference = Long.compare(lhs.read1IndexInFile, rhs.read1IndexInFile);
             }
             if (compareDifference == 0) {
-                compareDifference = (int) (lhs.read2IndexInFile - rhs.read2IndexInFile);
+                compareDifference = Long.compare(lhs.read2IndexInFile, rhs.read2IndexInFile);
             }
 
             return compareDifference;
