@@ -105,17 +105,12 @@ public class RenameSampleInVcf extends CommandLineProgram {
     @Argument(doc="New name to give sample in output VCF.")
     public String NEW_SAMPLE_NAME;
 
-
-    public static void main(final String[] args) {
-        new RenameSampleInVcf().instanceMainWithExit(args);
-    }
-
     @Override
     protected int doWork() {
         IOUtil.assertFileIsReadable(INPUT);
         IOUtil.assertFileIsWritable(OUTPUT);
 
-        final VCFFileReader in = new VCFFileReader(INPUT);
+        final VCFFileReader in = new VCFFileReader(INPUT, false);
         final VCFHeader header = in.getFileHeader();
 
         if (header.getGenotypeSamples().size() > 1) {
