@@ -25,12 +25,15 @@ package picard.vcf.processor;
 
 import htsjdk.samtools.util.IntervalList;
 import htsjdk.variant.variantcontext.VariantContext;
+import picard.nio.PicardHtsPath;
 
 import java.io.File;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.List;
+import java.util.stream.Collectors;
 
 /**
  * Describes an object that processes variants and produces a result.
@@ -40,7 +43,7 @@ import java.util.List;
  * <p/>
  * Future work...?
  * - Make more efficient for the single-thread case.
- * - A {@link VcfFileSegmentGenerator} that is based on an interval list, so that segments' span a constant-size total-base-count overlap with
+ * - A {@link VcfPathSegmentGenerator} that is based on an interval list, so that segments' span a constant-size total-base-count overlap with
  * the interval list (or something in that vein).
  *
  * @author mccowan
@@ -53,7 +56,7 @@ public class VariantProcessor<RESULT, ACCUMULATOR extends VariantProcessor.Accum
      *
      * @author mccowan
      */
-    public static interface Accumulator<RESULT> {
+    public interface Accumulator<RESULT> {
         void accumulate(final VariantContext vc);
 
         RESULT result();
@@ -64,7 +67,7 @@ public class VariantProcessor<RESULT, ACCUMULATOR extends VariantProcessor.Accum
      *
      * @author mccowan
      */
-    public static interface AccumulatorGenerator<ACCUMULATOR extends Accumulator<RESULT>, RESULT> {
+    public interface AccumulatorGenerator<ACCUMULATOR extends Accumulator<RESULT>, RESULT> {
         ACCUMULATOR build();
     }
 
@@ -73,7 +76,7 @@ public class VariantProcessor<RESULT, ACCUMULATOR extends VariantProcessor.Accum
      *
      * @author mccowan
      */
-    public static interface ResultMerger<RESULT> {
+    public interface ResultMerger<RESULT> {
         RESULT merge(final Collection<RESULT> resultsToReduce);
     }
 
@@ -96,7 +99,7 @@ public class VariantProcessor<RESULT, ACCUMULATOR extends VariantProcessor.Accum
             throw new RuntimeException(e);
         }
 
-        final List<RESULT> results = new ArrayList<RESULT>();
+        final List<RESULT> results = new ArrayList<>();
         for (final ACCUMULATOR a : executor.accumulators()) {
             results.add(a.result());
         }
@@ -108,7 +111,7 @@ public class VariantProcessor<RESULT, ACCUMULATOR extends VariantProcessor.Accum
         final AccumulatorGenerator<A, R> accumulatorGenerator;
         ResultMerger<R> reducer = null;
         IntervalList intervals = null;
-        final List<File> inputs = new ArrayList<File>();
+        final List<PicardHtsPath> inputs = new ArrayList<>();
         int threadCount = 1;
 
         Builder(final AccumulatorGenerator<A, R> accumulatorGenerator) {
@@ -122,6 +125,11 @@ public class VariantProcessor<RESULT, ACCUMULATOR extends VariantProcessor.Accum
         }
 
         public Builder<A, R> withInput(final File... vcfs) {
+            final List<PicardHtsPath> paths = Arrays.stream(vcfs).map(PicardHtsPath::new).collect(Collectors.toList());
+            return withInput(paths.toArray(new PicardHtsPath[]{}));
+        }
+
+        public Builder<A, R> withInput(final PicardHtsPath... vcfs) {
             Collections.addAll(inputs, vcfs);
             return this;
         }
@@ -139,14 +147,14 @@ public class VariantProcessor<RESULT, ACCUMULATOR extends VariantProcessor.Accum
         }
 
         public static <A extends Accumulator<R>, R> Builder<A, R> generatingAccumulatorsBy(final AccumulatorGenerator<A, R> generator) {
-            return new Builder<A, R>(generator);
+            return new Builder<>(generator);
         }
 
         public VariantProcessor<R, A> build() {
             if (inputs.isEmpty()) throw new IllegalStateException("You need to provided some inputs before building.");
             if (reducer == null) throw new IllegalStateException("You must provide a reducer before building.");
 
-            return new VariantProcessor<R, A>(reducer, new VariantAccumulatorExecutor.MultiThreadedChunkBased<A, R>(
+            return new VariantProcessor<>(reducer, new VariantAccumulatorExecutor.MultiThreadedChunkBased<>(
                     threadCount,
                     composeVcfIteratorProducerFromBuilderArguments(),
                     accumulatorGenerator
@@ -154,16 +162,16 @@ public class VariantProcessor<RESULT, ACCUMULATOR extends VariantProcessor.Accum
         }
 
         private VariantIteratorProducer composeVcfIteratorProducerFromBuilderArguments() {
-            /**
+            /*
              * Be careful; if we pick chunkings that are highly granular (e.g., a chunking based on each interval in an exome-like 
              * interval list), it will result in a {@link htsjdk.variant.vcf.VCFFileReader#query(String, int, int)} call
              * per tiny chunk, which is very non-performant due to some implementations of that method.
              */
             final VariantIteratorProducer ret;
             if (intervals == null) {
-                ret = VariantIteratorProducer.byHundredMegabaseChunks(inputs);
+                ret = VariantIteratorProducer.byHundredMegabasePathChunks(inputs);
             } else {
-                ret = VariantIteratorProducer.byHundredMegabaseChunksWithOnTheFlyFilteringByInterval(inputs, intervals);
+                ret = VariantIteratorProducer.byHundredMegabasePathChunksWithOnTheFlyFilteringByInterval(inputs, intervals);
             }
             return ret;
         }
